@@ -13,6 +13,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <glib-object.h>
 #include <gobject/gmarshal.h>
 #include <bonobo/Bonobo.h>
@@ -890,6 +893,9 @@ bonobo_object_class_init (BonoboObjectClass *klass)
 	g_assert (sizeof (POA_Bonobo_Unknown) == sizeof (gpointer) * 2);
 	g_assert (sizeof (BonoboObjectHeader) * 2 == sizeof (BonoboObject));
 
+	if (G_UNLIKELY (!bonobo_is_initialized()) )
+		g_warning ("Bonobo must be initialized before use");
+	
 	bonobo_object_parent_class = g_type_class_peek_parent (klass);
 
 	object_class->set_property = bonobo_object_set_property;
